package Qt::Gui::QWidgetItemV2;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QWidgetItemV2
# file     : QtGui/qlayoutitem.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QWidgetItem/;
#our @ISA = qw/Qt::Gui::QWidgetItem/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QWidgetItemV2

=head1 PUBLIC METHODS

=over

=item   QWidgetItemV2(QWidget * widget)

=item   ~QWidgetItemV2()

=item  int heightForWidth(int width)

=item  QSize maximumSize()

=item  QSize minimumSize()

=item  QSize sizeHint()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
